@@ -45,4 +45,4 @@ class TemplateTags(object): # pragma: no cover
     
         
     def __exit__(self, type, value, traceback):
-        template.builtins = self.old
\ No newline at end of file
+        template.builtins[:] = self.old
\ No newline at end of file
